gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet] branch master updated: minor fixes


From: gnunet
Subject: [gnunet] branch master updated: minor fixes
Date: Sat, 19 Dec 2020 19:30:58 +0100

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository gnunet.

The following commit(s) were added to refs/heads/master by this push:
     new 0876272a7 minor fixes
0876272a7 is described below

commit 0876272a77b7fbcf8e662dccf463e5fca9ea9acf
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Sat Dec 19 19:30:31 2020 +0100

    minor fixes
---
 src/include/gnunet_disk_lib.h | 8 ++++----
 src/testbed/gnunet_mpi_test.c | 1 +
 2 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/src/testbed/gnunet_mpi_test.c b/src/testbed/gnunet_mpi_test.c
index 241e5c53e..2ee707fe6 100644
--- a/src/testbed/gnunet_mpi_test.c
+++ b/src/testbed/gnunet_mpi_test.c
@@ -49,6 +49,7 @@ main (int argc, char *argv[])
   (void) GNUNET_asprintf (&filename, "%d-%d.mpiout", (int) pid, rank);
   msg_size = GNUNET_asprintf (&msg, "My rank is: %d\n", rank);
   printf ("%s", msg);
+  (void) GNUNET_DISK_directory_remove (filename);
   if (GNUNET_OK ==
       GNUNET_DISK_fn_write (filename, msg, msg_size,
                             GNUNET_DISK_PERM_USER_READ

diff --git a/src/include/gnunet_disk_lib.h b/src/include/gnunet_disk_lib.h
index b794088c4..e45ab84f4 100644
--- a/src/include/gnunet_disk_lib.h
+++ b/src/include/gnunet_disk_lib.h
@@ -614,8 +614,8 @@ GNUNET_DISK_file_write_blocking (const struct 
GNUNET_DISK_FileHandle *h,
  * with @a buf_size bytes could be written to @a filename.
  *
  * @param fn file name
  * @param buffer the data to write
  * @param n number of bytes to write
  * @param mode file permissions
  * @return #GNUNET_OK on success,
  *         #GNUNET_NO if a file existed under @a filename
@@ -623,8 +623,8 @@ GNUNET_DISK_file_write_blocking (const struct 
GNUNET_DISK_FileHandle *h,
  */
 enum GNUNET_GenericReturnValue
 GNUNET_DISK_fn_write (const char *fn,
-                      const void *buffer,
-                      size_t n,
+                      const void *buf,
+                      size_t buf_size,
                       enum GNUNET_DISK_AccessPermissions mode);
 
 
@@ -614,8 +614,8 @@ GNUNET_DISK_file_write_blocking (const struct 
  *
  * @param fn file name
- * @param buffer the data to write
- * @param n number of bytes to write
+ * @param buf the data to write
+ * @param buf_size number of bytes to write from @a buf
  * @param mode file permissions
  * @return #GNUNET_OK on success,
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]